from gogoproto import gogo_pb2 as _gogo_pb2
from ibc.core.client.v1 import genesis_pb2 as _genesis_pb2
from ibc.core.connection.v1 import genesis_pb2 as _genesis_pb2_1
from ibc.core.channel.v1 import genesis_pb2 as _genesis_pb2_1_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("client_genesis", "connection_genesis", "channel_genesis")
    CLIENT_GENESIS_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_GENESIS_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_GENESIS_FIELD_NUMBER: _ClassVar[int]
    client_genesis: _genesis_pb2.GenesisState
    connection_genesis: _genesis_pb2_1.GenesisState
    channel_genesis: _genesis_pb2_1_1.GenesisState
    def __init__(self, client_genesis: _Optional[_Union[_genesis_pb2.GenesisState, _Mapping]] = ..., connection_genesis: _Optional[_Union[_genesis_pb2_1.GenesisState, _Mapping]] = ..., channel_genesis: _Optional[_Union[_genesis_pb2_1_1.GenesisState, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from neurion.sanctum import query_pb2 as neurion_dot_sanctum_dot_query__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in neurion/sanctum/query_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/neurion.sanctum.Query/Params',
                request_serializer=neurion_dot_sanctum_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)
        self.GetAvailableDatasets = channel.unary_unary(
                '/neurion.sanctum.Query/GetAvailableDatasets',
                request_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetAvailableDatasetsRequest.SerializeToString,
                response_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetAvailableDatasetsResponse.FromString,
                _registered_method=True)
        self.GetApprovedUsageRequests = channel.unary_unary(
                '/neurion.sanctum.Query/GetApprovedUsageRequests',
                request_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetApprovedUsageRequestsRequest.SerializeToString,
                response_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetApprovedUsageRequestsResponse.FromString,
                _registered_method=True)
        self.GetReward = channel.unary_unary(
                '/neurion.sanctum.Query/GetReward',
                request_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetRewardRequest.SerializeToString,
                response_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetRewardResponse.FromString,
                _registered_method=True)
        self.GetStake = channel.unary_unary(
                '/neurion.sanctum.Query/GetStake',
                request_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetStakeRequest.SerializeToString,
                response_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetStakeResponse.FromString,
                _registered_method=True)
        self.GetPendingDatasets = channel.unary_unary(
                '/neurion.sanctum.Query/GetPendingDatasets',
                request_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetPendingDatasetsRequest.SerializeToString,
                response_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetPendingDatasetsResponse.FromString,
                _registered_method=True)
        self.GetPendingUsageRequests = channel.unary_unary(
                '/neurion.sanctum.Query/GetPendingUsageRequests',
                request_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetPendingUsageRequestsRequest.SerializeToString,
                response_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetPendingUsageRequestsResponse.FromString,
                _registered_method=True)
        self.GetDataset = channel.unary_unary(
                '/neurion.sanctum.Query/GetDataset',
                request_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetDatasetRequest.SerializeToString,
                response_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetDatasetResponse.FromString,
                _registered_method=True)
        self.GetUsageRequest = channel.unary_unary(
                '/neurion.sanctum.Query/GetUsageRequest',
                request_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestRequest.SerializeToString,
                response_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestResponse.FromString,
                _registered_method=True)
        self.GetUsageRequestsForDataset = channel.unary_unary(
                '/neurion.sanctum.Query/GetUsageRequestsForDataset',
                request_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestsForDatasetRequest.SerializeToString,
                response_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestsForDatasetResponse.FromString,
                _registered_method=True)
        self.GetUsageRequestsForUser = channel.unary_unary(
                '/neurion.sanctum.Query/GetUsageRequestsForUser',
                request_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestsForUserRequest.SerializeToString,
                response_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestsForUserResponse.FromString,
                _registered_method=True)
        self.GetDatasetsForUser = channel.unary_unary(
                '/neurion.sanctum.Query/GetDatasetsForUser',
                request_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetDatasetsForUserRequest.SerializeToString,
                response_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetDatasetsForUserResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Params(self, request, context):
        """Parameters queries the parameters of the module.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAvailableDatasets(self, request, context):
        """Queries a list of GetAvailableDatasets items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetApprovedUsageRequests(self, request, context):
        """Queries a list of GetApprovedUsageRequests items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReward(self, request, context):
        """Queries a list of GetReward items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStake(self, request, context):
        """Queries a list of GetStake items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPendingDatasets(self, request, context):
        """Queries a list of GetPendingDatasets items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPendingUsageRequests(self, request, context):
        """Queries a list of GetPendingUsageRequests items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataset(self, request, context):
        """Queries a list of GetDataset items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUsageRequest(self, request, context):
        """Queries a list of GetUsageRequest items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUsageRequestsForDataset(self, request, context):
        """Queries a list of GetUsageRequestsForDataset items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUsageRequestsForUser(self, request, context):
        """Queries a list of GetUsageRequestsForUser items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDatasetsForUser(self, request, context):
        """Queries a list of GetDatasetsForUser items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=neurion_dot_sanctum_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'GetAvailableDatasets': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAvailableDatasets,
                    request_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetAvailableDatasetsRequest.FromString,
                    response_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetAvailableDatasetsResponse.SerializeToString,
            ),
            'GetApprovedUsageRequests': grpc.unary_unary_rpc_method_handler(
                    servicer.GetApprovedUsageRequests,
                    request_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetApprovedUsageRequestsRequest.FromString,
                    response_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetApprovedUsageRequestsResponse.SerializeToString,
            ),
            'GetReward': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReward,
                    request_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetRewardRequest.FromString,
                    response_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetRewardResponse.SerializeToString,
            ),
            'GetStake': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStake,
                    request_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetStakeRequest.FromString,
                    response_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetStakeResponse.SerializeToString,
            ),
            'GetPendingDatasets': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPendingDatasets,
                    request_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetPendingDatasetsRequest.FromString,
                    response_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetPendingDatasetsResponse.SerializeToString,
            ),
            'GetPendingUsageRequests': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPendingUsageRequests,
                    request_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetPendingUsageRequestsRequest.FromString,
                    response_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetPendingUsageRequestsResponse.SerializeToString,
            ),
            'GetDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataset,
                    request_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetDatasetRequest.FromString,
                    response_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetDatasetResponse.SerializeToString,
            ),
            'GetUsageRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUsageRequest,
                    request_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestRequest.FromString,
                    response_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestResponse.SerializeToString,
            ),
            'GetUsageRequestsForDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUsageRequestsForDataset,
                    request_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestsForDatasetRequest.FromString,
                    response_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestsForDatasetResponse.SerializeToString,
            ),
            'GetUsageRequestsForUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUsageRequestsForUser,
                    request_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestsForUserRequest.FromString,
                    response_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestsForUserResponse.SerializeToString,
            ),
            'GetDatasetsForUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDatasetsForUser,
                    request_deserializer=neurion_dot_sanctum_dot_query__pb2.QueryGetDatasetsForUserRequest.FromString,
                    response_serializer=neurion_dot_sanctum_dot_query__pb2.QueryGetDatasetsForUserResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'neurion.sanctum.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('neurion.sanctum.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.sanctum.Query/Params',
            neurion_dot_sanctum_dot_query__pb2.QueryParamsRequest.SerializeToString,
            neurion_dot_sanctum_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAvailableDatasets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.sanctum.Query/GetAvailableDatasets',
            neurion_dot_sanctum_dot_query__pb2.QueryGetAvailableDatasetsRequest.SerializeToString,
            neurion_dot_sanctum_dot_query__pb2.QueryGetAvailableDatasetsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetApprovedUsageRequests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.sanctum.Query/GetApprovedUsageRequests',
            neurion_dot_sanctum_dot_query__pb2.QueryGetApprovedUsageRequestsRequest.SerializeToString,
            neurion_dot_sanctum_dot_query__pb2.QueryGetApprovedUsageRequestsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetReward(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.sanctum.Query/GetReward',
            neurion_dot_sanctum_dot_query__pb2.QueryGetRewardRequest.SerializeToString,
            neurion_dot_sanctum_dot_query__pb2.QueryGetRewardResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetStake(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.sanctum.Query/GetStake',
            neurion_dot_sanctum_dot_query__pb2.QueryGetStakeRequest.SerializeToString,
            neurion_dot_sanctum_dot_query__pb2.QueryGetStakeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPendingDatasets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.sanctum.Query/GetPendingDatasets',
            neurion_dot_sanctum_dot_query__pb2.QueryGetPendingDatasetsRequest.SerializeToString,
            neurion_dot_sanctum_dot_query__pb2.QueryGetPendingDatasetsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPendingUsageRequests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.sanctum.Query/GetPendingUsageRequests',
            neurion_dot_sanctum_dot_query__pb2.QueryGetPendingUsageRequestsRequest.SerializeToString,
            neurion_dot_sanctum_dot_query__pb2.QueryGetPendingUsageRequestsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.sanctum.Query/GetDataset',
            neurion_dot_sanctum_dot_query__pb2.QueryGetDatasetRequest.SerializeToString,
            neurion_dot_sanctum_dot_query__pb2.QueryGetDatasetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUsageRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.sanctum.Query/GetUsageRequest',
            neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestRequest.SerializeToString,
            neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUsageRequestsForDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.sanctum.Query/GetUsageRequestsForDataset',
            neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestsForDatasetRequest.SerializeToString,
            neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestsForDatasetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUsageRequestsForUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.sanctum.Query/GetUsageRequestsForUser',
            neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestsForUserRequest.SerializeToString,
            neurion_dot_sanctum_dot_query__pb2.QueryGetUsageRequestsForUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDatasetsForUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.sanctum.Query/GetDatasetsForUser',
            neurion_dot_sanctum_dot_query__pb2.QueryGetDatasetsForUserRequest.SerializeToString,
            neurion_dot_sanctum_dot_query__pb2.QueryGetDatasetsForUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from tendermint.types import validator_pb2 as _validator_pb2
from tendermint.types import types_pb2 as _types_pb2
import proofs_pb2 as _proofs_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from ibc.core.client.v1 import client_pb2 as _client_pb2
from ibc.core.commitment.v1 import commitment_pb2 as _commitment_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ClientState(_message.Message):
    __slots__ = ("chain_id", "trust_level", "trusting_period", "unbonding_period", "max_clock_drift", "frozen_height", "latest_height", "proof_specs", "upgrade_path", "allow_update_after_expiry", "allow_update_after_misbehaviour")
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    TRUST_LEVEL_FIELD_NUMBER: _ClassVar[int]
    TRUSTING_PERIOD_FIELD_NUMBER: _ClassVar[int]
    UNBONDING_PERIOD_FIELD_NUMBER: _ClassVar[int]
    MAX_CLOCK_DRIFT_FIELD_NUMBER: _ClassVar[int]
    FROZEN_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    LATEST_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PROOF_SPECS_FIELD_NUMBER: _ClassVar[int]
    UPGRADE_PATH_FIELD_NUMBER: _ClassVar[int]
    ALLOW_UPDATE_AFTER_EXPIRY_FIELD_NUMBER: _ClassVar[int]
    ALLOW_UPDATE_AFTER_MISBEHAVIOUR_FIELD_NUMBER: _ClassVar[int]
    chain_id: str
    trust_level: Fraction
    trusting_period: _duration_pb2.Duration
    unbonding_period: _duration_pb2.Duration
    max_clock_drift: _duration_pb2.Duration
    frozen_height: _client_pb2.Height
    latest_height: _client_pb2.Height
    proof_specs: _containers.RepeatedCompositeFieldContainer[_proofs_pb2.ProofSpec]
    upgrade_path: _containers.RepeatedScalarFieldContainer[str]
    allow_update_after_expiry: bool
    allow_update_after_misbehaviour: bool
    def __init__(self, chain_id: _Optional[str] = ..., trust_level: _Optional[_Union[Fraction, _Mapping]] = ..., trusting_period: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., unbonding_period: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., max_clock_drift: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., frozen_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., latest_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., proof_specs: _Optional[_Iterable[_Union[_proofs_pb2.ProofSpec, _Mapping]]] = ..., upgrade_path: _Optional[_Iterable[str]] = ..., allow_update_after_expiry: bool = ..., allow_update_after_misbehaviour: bool = ...) -> None: ...

class ConsensusState(_message.Message):
    __slots__ = ("timestamp", "root", "next_validators_hash")
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    ROOT_FIELD_NUMBER: _ClassVar[int]
    NEXT_VALIDATORS_HASH_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    root: _commitment_pb2.MerkleRoot
    next_validators_hash: bytes
    def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., root: _Optional[_Union[_commitment_pb2.MerkleRoot, _Mapping]] = ..., next_validators_hash: _Optional[bytes] = ...) -> None: ...

class Misbehaviour(_message.Message):
    __slots__ = ("client_id", "header_1", "header_2")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    HEADER_1_FIELD_NUMBER: _ClassVar[int]
    HEADER_2_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    header_1: Header
    header_2: Header
    def __init__(self, client_id: _Optional[str] = ..., header_1: _Optional[_Union[Header, _Mapping]] = ..., header_2: _Optional[_Union[Header, _Mapping]] = ...) -> None: ...

class Header(_message.Message):
    __slots__ = ("signed_header", "validator_set", "trusted_height", "trusted_validators")
    SIGNED_HEADER_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_SET_FIELD_NUMBER: _ClassVar[int]
    TRUSTED_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TRUSTED_VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    signed_header: _types_pb2.SignedHeader
    validator_set: _validator_pb2.ValidatorSet
    trusted_height: _client_pb2.Height
    trusted_validators: _validator_pb2.ValidatorSet
    def __init__(self, signed_header: _Optional[_Union[_types_pb2.SignedHeader, _Mapping]] = ..., validator_set: _Optional[_Union[_validator_pb2.ValidatorSet, _Mapping]] = ..., trusted_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., trusted_validators: _Optional[_Union[_validator_pb2.ValidatorSet, _Mapping]] = ...) -> None: ...

class Fraction(_message.Message):
    __slots__ = ("numerator", "denominator")
    NUMERATOR_FIELD_NUMBER: _ClassVar[int]
    DENOMINATOR_FIELD_NUMBER: _ClassVar[int]
    numerator: int
    denominator: int
    def __init__(self, numerator: _Optional[int] = ..., denominator: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/fusion/tx.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/fusion/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from neurion.fusion import params_pb2 as neurion_dot_fusion_dot_params__pb2
from neurion.fusion import task_pb2 as neurion_dot_fusion_dot_task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17neurion/fusion/tx.proto\x12\x0eneurion.fusion\x1a\x11\x61mino/amino.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1bneurion/fusion/params.proto\x1a\x19neurion/fusion/task.proto\"\xa6\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x31\n\x06params\x18\x02 \x01(\x0b\x32\x16.neurion.fusion.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:3\x82\xe7\xb0*\tauthority\x8a\xe7\xb0* neurion/x/fusion/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"E\n\x0fMsgApplyCreator\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x19\n\x17MsgApplyCreatorResponse\"^\n\x15MsgApproveApplication\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1f\n\x1dMsgApproveApplicationResponse\"]\n\x14MsgRejectApplication\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1e\n\x1cMsgRejectApplicationResponse\"\x89\x01\n\rMsgCreateTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nbase_model\x18\x02 \x01(\t\x12\x12\n\nmax_rounds\x18\x03 \x01(\x04\x12\x0e\n\x06reward\x18\x04 \x01(\x04\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"F\n\x15MsgCreateTaskResponse\x12-\n\x04task\x18\x01 \x01(\x0b\x32\x14.neurion.fusion.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\">\n\x0cMsgStartTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"E\n\x14MsgStartTaskResponse\x12-\n\x04task\x18\x01 \x01(\x0b\x32\x14.neurion.fusion.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"q\n\x0fMsgProposeModel\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\r\n\x05model\x18\x03 \x01(\t\x12\x10\n\x08metainfo\x18\x04 \x01(\t\x12\r\n\x05round\x18\x06 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x19\n\x17MsgProposeModelResponse\"T\n\x13MsgRegisterProposer\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\r\n\x05stake\x18\x02 \x01(\x04\x12\x0f\n\x07task_id\x18\x03 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1d\n\x1bMsgRegisterProposerResponse\"U\n\x14MsgRegisterValidator\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\r\n\x05stake\x18\x02 \x01(\x04\x12\x0f\n\x07task_id\x18\x03 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1e\n\x1cMsgRegisterValidatorResponse\"a\n\x0fMsgStartTesting\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\r\n\x05round\x18\x02 \x01(\x04\x12\x0f\n\x07testset\x18\x03 \x01(\t\x12\x0f\n\x07task_id\x18\x04 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x19\n\x17MsgStartTestingResponse\"J\n\x18MsgRequestValidationTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\"\n MsgRequestValidationTaskResponse\"Z\n\x0eMsgSubmitScore\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x1a\n\x12validation_task_id\x18\x02 \x01(\x04\x12\r\n\x05score\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x18\n\x16MsgSubmitScoreResponse\"V\n\x14MsgDisputeModelScore\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\x04\x12\r\n\x05score\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1e\n\x1cMsgDisputeModelScoreResponse\"e\n\x10MsgStartNewRound\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\r\n\x05round\x18\x02 \x01(\x04\x12\x12\n\nbase_model\x18\x03 \x01(\t\x12\x0f\n\x07task_id\x18\x04 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1a\n\x18MsgStartNewRoundResponse\"B\n\x10MsgTerminateTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1a\n\x18MsgTerminateTaskResponse\"P\n\x0eMsgStakeToTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x18\n\x16MsgStakeToTaskResponse\"D\n\x12MsgClaimTaskReward\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgClaimTaskRewardResponse\"D\n\x12MsgUnstakeFromTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgUnstakeFromTaskResponse\"I\n\x18MsgDisclaimCreatorStatus\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\"\n MsgDisclaimCreatorStatusResponse\">\n\x0cMsgAbortTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x16\n\x14MsgAbortTaskResponse2\x8f\x0f\n\x03Msg\x12X\n\x0cUpdateParams\x12\x1f.neurion.fusion.MsgUpdateParams\x1a\'.neurion.fusion.MsgUpdateParamsResponse\x12X\n\x0c\x41pplyCreator\x12\x1f.neurion.fusion.MsgApplyCreator\x1a\'.neurion.fusion.MsgApplyCreatorResponse\x12j\n\x12\x41pproveApplication\x12%.neurion.fusion.MsgApproveApplication\x1a-.neurion.fusion.MsgApproveApplicationResponse\x12g\n\x11RejectApplication\x12$.neurion.fusion.MsgRejectApplication\x1a,.neurion.fusion.MsgRejectApplicationResponse\x12R\n\nCreateTask\x12\x1d.neurion.fusion.MsgCreateTask\x1a%.neurion.fusion.MsgCreateTaskResponse\x12O\n\tStartTask\x12\x1c.neurion.fusion.MsgStartTask\x1a$.neurion.fusion.MsgStartTaskResponse\x12X\n\x0cProposeModel\x12\x1f.neurion.fusion.MsgProposeModel\x1a\'.neurion.fusion.MsgProposeModelResponse\x12\x64\n\x10RegisterProposer\x12#.neurion.fusion.MsgRegisterProposer\x1a+.neurion.fusion.MsgRegisterProposerResponse\x12g\n\x11RegisterValidator\x12$.neurion.fusion.MsgRegisterValidator\x1a,.neurion.fusion.MsgRegisterValidatorResponse\x12X\n\x0cStartTesting\x12\x1f.neurion.fusion.MsgStartTesting\x1a\'.neurion.fusion.MsgStartTestingResponse\x12s\n\x15RequestValidationTask\x12(.neurion.fusion.MsgRequestValidationTask\x1a\x30.neurion.fusion.MsgRequestValidationTaskResponse\x12U\n\x0bSubmitScore\x12\x1e.neurion.fusion.MsgSubmitScore\x1a&.neurion.fusion.MsgSubmitScoreResponse\x12g\n\x11\x44isputeModelScore\x12$.neurion.fusion.MsgDisputeModelScore\x1a,.neurion.fusion.MsgDisputeModelScoreResponse\x12[\n\rStartNewRound\x12 .neurion.fusion.MsgStartNewRound\x1a(.neurion.fusion.MsgStartNewRoundResponse\x12[\n\rTerminateTask\x12 .neurion.fusion.MsgTerminateTask\x1a(.neurion.fusion.MsgTerminateTaskResponse\x12U\n\x0bStakeToTask\x12\x1e.neurion.fusion.MsgStakeToTask\x1a&.neurion.fusion.MsgStakeToTaskResponse\x12\x61\n\x0f\x43laimTaskReward\x12\".neurion.fusion.MsgClaimTaskReward\x1a*.neurion.fusion.MsgClaimTaskRewardResponse\x12\x61\n\x0fUnstakeFromTask\x12\".neurion.fusion.MsgUnstakeFromTask\x1a*.neurion.fusion.MsgUnstakeFromTaskResponse\x12s\n\x15\x44isclaimCreatorStatus\x12(.neurion.fusion.MsgDisclaimCreatorStatus\x1a\x30.neurion.fusion.MsgDisclaimCreatorStatusResponse\x12O\n\tAbortTask\x12\x1c.neurion.fusion.MsgAbortTask\x1a$.neurion.fusion.MsgAbortTaskResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x18Z\x16neurion/x/fusion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.fusion.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\026neurion/x/fusion/types'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260* neurion/x/fusion/MsgUpdateParams'
  _globals['_MSGAPPLYCREATOR']._loaded_options = None
  _globals['_MSGAPPLYCREATOR']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGAPPROVEAPPLICATION']._loaded_options = None
  _globals['_MSGAPPROVEAPPLICATION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREJECTAPPLICATION']._loaded_options = None
  _globals['_MSGREJECTAPPLICATION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCREATETASK']._loaded_options = None
  _globals['_MSGCREATETASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCREATETASKRESPONSE'].fields_by_name['task']._loaded_options = None
  _globals['_MSGCREATETASKRESPONSE'].fields_by_name['task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGSTARTTASK']._loaded_options = None
  _globals['_MSGSTARTTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSTARTTASKRESPONSE'].fields_by_name['task']._loaded_options = None
  _globals['_MSGSTARTTASKRESPONSE'].fields_by_name['task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGPROPOSEMODEL']._loaded_options = None
  _globals['_MSGPROPOSEMODEL']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREGISTERPROPOSER']._loaded_options = None
  _globals['_MSGREGISTERPROPOSER']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREGISTERVALIDATOR']._loaded_options = None
  _globals['_MSGREGISTERVALIDATOR']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSTARTTESTING']._loaded_options = None
  _globals['_MSGSTARTTESTING']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREQUESTVALIDATIONTASK']._loaded_options = None
  _globals['_MSGREQUESTVALIDATIONTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSUBMITSCORE']._loaded_options = None
  _globals['_MSGSUBMITSCORE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGDISPUTEMODELSCORE']._loaded_options = None
  _globals['_MSGDISPUTEMODELSCORE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSTARTNEWROUND']._loaded_options = None
  _globals['_MSGSTARTNEWROUND']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGTERMINATETASK']._loaded_options = None
  _globals['_MSGTERMINATETASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSTAKETOTASK']._loaded_options = None
  _globals['_MSGSTAKETOTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCLAIMTASKREWARD']._loaded_options = None
  _globals['_MSGCLAIMTASKREWARD']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGUNSTAKEFROMTASK']._loaded_options = None
  _globals['_MSGUNSTAKEFROMTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGDISCLAIMCREATORSTATUS']._loaded_options = None
  _globals['_MSGDISCLAIMCREATORSTATUS']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGABORTTASK']._loaded_options = None
  _globals['_MSGABORTTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._serialized_start=193
  _globals['_MSGUPDATEPARAMS']._serialized_end=359
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=361
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=386
  _globals['_MSGAPPLYCREATOR']._serialized_start=388
  _globals['_MSGAPPLYCREATOR']._serialized_end=457
  _globals['_MSGAPPLYCREATORRESPONSE']._serialized_start=459
  _globals['_MSGAPPLYCREATORRESPONSE']._serialized_end=484
  _globals['_MSGAPPROVEAPPLICATION']._serialized_start=486
  _globals['_MSGAPPROVEAPPLICATION']._serialized_end=580
  _globals['_MSGAPPROVEAPPLICATIONRESPONSE']._serialized_start=582
  _globals['_MSGAPPROVEAPPLICATIONRESPONSE']._serialized_end=613
  _globals['_MSGREJECTAPPLICATION']._serialized_start=615
  _globals['_MSGREJECTAPPLICATION']._serialized_end=708
  _globals['_MSGREJECTAPPLICATIONRESPONSE']._serialized_start=710
  _globals['_MSGREJECTAPPLICATIONRESPONSE']._serialized_end=740
  _globals['_MSGCREATETASK']._serialized_start=743
  _globals['_MSGCREATETASK']._serialized_end=880
  _globals['_MSGCREATETASKRESPONSE']._serialized_start=882
  _globals['_MSGCREATETASKRESPONSE']._serialized_end=952
  _globals['_MSGSTARTTASK']._serialized_start=954
  _globals['_MSGSTARTTASK']._serialized_end=1016
  _globals['_MSGSTARTTASKRESPONSE']._serialized_start=1018
  _globals['_MSGSTARTTASKRESPONSE']._serialized_end=1087
  _globals['_MSGPROPOSEMODEL']._serialized_start=1089
  _globals['_MSGPROPOSEMODEL']._serialized_end=1202
  _globals['_MSGPROPOSEMODELRESPONSE']._serialized_start=1204
  _globals['_MSGPROPOSEMODELRESPONSE']._serialized_end=1229
  _globals['_MSGREGISTERPROPOSER']._serialized_start=1231
  _globals['_MSGREGISTERPROPOSER']._serialized_end=1315
  _globals['_MSGREGISTERPROPOSERRESPONSE']._serialized_start=1317
  _globals['_MSGREGISTERPROPOSERRESPONSE']._serialized_end=1346
  _globals['_MSGREGISTERVALIDATOR']._serialized_start=1348
  _globals['_MSGREGISTERVALIDATOR']._serialized_end=1433
  _globals['_MSGREGISTERVALIDATORRESPONSE']._serialized_start=1435
  _globals['_MSGREGISTERVALIDATORRESPONSE']._serialized_end=1465
  _globals['_MSGSTARTTESTING']._serialized_start=1467
  _globals['_MSGSTARTTESTING']._serialized_end=1564
  _globals['_MSGSTARTTESTINGRESPONSE']._serialized_start=1566
  _globals['_MSGSTARTTESTINGRESPONSE']._serialized_end=1591
  _globals['_MSGREQUESTVALIDATIONTASK']._serialized_start=1593
  _globals['_MSGREQUESTVALIDATIONTASK']._serialized_end=1667
  _globals['_MSGREQUESTVALIDATIONTASKRESPONSE']._serialized_start=1669
  _globals['_MSGREQUESTVALIDATIONTASKRESPONSE']._serialized_end=1703
  _globals['_MSGSUBMITSCORE']._serialized_start=1705
  _globals['_MSGSUBMITSCORE']._serialized_end=1795
  _globals['_MSGSUBMITSCORERESPONSE']._serialized_start=1797
  _globals['_MSGSUBMITSCORERESPONSE']._serialized_end=1821
  _globals['_MSGDISPUTEMODELSCORE']._serialized_start=1823
  _globals['_MSGDISPUTEMODELSCORE']._serialized_end=1909
  _globals['_MSGDISPUTEMODELSCORERESPONSE']._serialized_start=1911
  _globals['_MSGDISPUTEMODELSCORERESPONSE']._serialized_end=1941
  _globals['_MSGSTARTNEWROUND']._serialized_start=1943
  _globals['_MSGSTARTNEWROUND']._serialized_end=2044
  _globals['_MSGSTARTNEWROUNDRESPONSE']._serialized_start=2046
  _globals['_MSGSTARTNEWROUNDRESPONSE']._serialized_end=2072
  _globals['_MSGTERMINATETASK']._serialized_start=2074
  _globals['_MSGTERMINATETASK']._serialized_end=2140
  _globals['_MSGTERMINATETASKRESPONSE']._serialized_start=2142
  _globals['_MSGTERMINATETASKRESPONSE']._serialized_end=2168
  _globals['_MSGSTAKETOTASK']._serialized_start=2170
  _globals['_MSGSTAKETOTASK']._serialized_end=2250
  _globals['_MSGSTAKETOTASKRESPONSE']._serialized_start=2252
  _globals['_MSGSTAKETOTASKRESPONSE']._serialized_end=2276
  _globals['_MSGCLAIMTASKREWARD']._serialized_start=2278
  _globals['_MSGCLAIMTASKREWARD']._serialized_end=2346
  _globals['_MSGCLAIMTASKREWARDRESPONSE']._serialized_start=2348
  _globals['_MSGCLAIMTASKREWARDRESPONSE']._serialized_end=2376
  _globals['_MSGUNSTAKEFROMTASK']._serialized_start=2378
  _globals['_MSGUNSTAKEFROMTASK']._serialized_end=2446
  _globals['_MSGUNSTAKEFROMTASKRESPONSE']._serialized_start=2448
  _globals['_MSGUNSTAKEFROMTASKRESPONSE']._serialized_end=2476
  _globals['_MSGDISCLAIMCREATORSTATUS']._serialized_start=2478
  _globals['_MSGDISCLAIMCREATORSTATUS']._serialized_end=2551
  _globals['_MSGDISCLAIMCREATORSTATUSRESPONSE']._serialized_start=2553
  _globals['_MSGDISCLAIMCREATORSTATUSRESPONSE']._serialized_end=2587
  _globals['_MSGABORTTASK']._serialized_start=2589
  _globals['_MSGABORTTASK']._serialized_end=2651
  _globals['_MSGABORTTASKRESPONSE']._serialized_start=2653
  _globals['_MSGABORTTASKRESPONSE']._serialized_end=2675
  _globals['_MSG']._serialized_start=2678
  _globals['_MSG']._serialized_end=4613
# @@protoc_insertion_point(module_scope)



from google.protobuf.json_format import Parse

from neurionpy.auth.interface import Auth
from neurionpy.common.rest_client import RestClient
from neurionpy.protos.cosmos.auth.v1beta1.query_pb2 import (
    QueryAccountRequest,
    QueryAccountResponse,
    QueryParamsRequest,
    QueryParamsResponse,
)


class AuthRestClient(Auth):
    """Auth REST client."""

    API_URL = "/cosmos/auth/v1beta1"

    def __init__(self, rest_api: RestClient):
        """
        Initialize authentication rest client.

        :param rest_api: RestClient api
        """
        self._rest_api = rest_api

    def Account(self, request: QueryAccountRequest) -> QueryAccountResponse:
        """
        Query account data - sequence, account_id, etc.

        :param request: QueryAccountRequest that contains account address

        :return: QueryAccountResponse
        """
        json_response = self._rest_api.get(f"{self.API_URL}/accounts/{request.address}")
        return Parse(json_response, QueryAccountResponse())

    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """
        Query all parameters.

        :param request: QueryParamsRequest

        :return: QueryParamsResponse
        """
        json_response = self._rest_api.get(f"{self.API_URL}/params")
        return Parse(json_response, QueryParamsResponse())



from abc import ABC, abstractmethod

from neurionpy.protos.cosmos.distribution.v1beta1.query_pb2 import (
    QueryCommunityPoolResponse,
    QueryDelegationRewardsRequest,
    QueryDelegationRewardsResponse,
    QueryDelegationTotalRewardsRequest,
    QueryDelegationTotalRewardsResponse,
    QueryDelegatorValidatorsRequest,
    QueryDelegatorValidatorsResponse,
    QueryDelegatorWithdrawAddressRequest,
    QueryDelegatorWithdrawAddressResponse,
    QueryParamsResponse,
    QueryValidatorCommissionRequest,
    QueryValidatorCommissionResponse,
    QueryValidatorOutstandingRewardsRequest,
    QueryValidatorOutstandingRewardsResponse,
    QueryValidatorSlashesRequest,
    QueryValidatorSlashesResponse,
)


class Distribution(ABC):
    """Distribution abstract class."""

    @abstractmethod
    def CommunityPool(self) -> QueryCommunityPoolResponse:
        """
        CommunityPool queries the community pool coins.

        :return: a QueryCommunityPoolResponse instance
        """

    @abstractmethod
    def DelegationTotalRewards(
        self, request: QueryDelegationTotalRewardsRequest
    ) -> QueryDelegationTotalRewardsResponse:
        """
        DelegationTotalRewards queries the total rewards accrued by each validator.

        :param request: a QueryDelegationTotalRewardsRequest instance
        :return: a QueryDelegationTotalRewardsResponse instance
        """

    @abstractmethod
    def DelegationRewards(
        self, request: QueryDelegationRewardsRequest
    ) -> QueryDelegationRewardsResponse:
        """
        DelegationRewards queries the total rewards accrued by a delegation.

        :param request: a QueryDelegationRewardsRequest instance
        :return: a QueryDelegationRewardsResponse instance
        """

    @abstractmethod
    def DelegatorValidators(
        self, request: QueryDelegatorValidatorsRequest
    ) -> QueryDelegatorValidatorsResponse:
        """
        DelegatorValidators queries the validators of a delegator.

        :param request: a QueryDelegatorValidatorsRequest instance
        :return: a QueryDelegatorValidatorsResponse instance
        """

    @abstractmethod
    def DelegatorWithdrawAddress(
        self, request: QueryDelegatorWithdrawAddressRequest
    ) -> QueryDelegatorWithdrawAddressResponse:
        """
        DelegatorWithdrawAddress queries withdraw address of a delegator.

        :param request: a QueryDelegatorWithdrawAddressRequest instance
        :return: a QueryDelegatorWithdrawAddressResponse instance
        """

    @abstractmethod
    def Params(self) -> QueryParamsResponse:
        """
        Params queries params of the distribution module.

        :return: a QueryParamsResponse instance
        """

    @abstractmethod
    def ValidatorCommission(
        self, request: QueryValidatorCommissionRequest
    ) -> QueryValidatorCommissionResponse:
        """
        ValidatorCommission queries accumulated commission for a validator.

        :param request: QueryValidatorCommissionRequest
        :return: QueryValidatorCommissionResponse
        """

    @abstractmethod
    def ValidatorOutstandingRewards(
        self, request: QueryValidatorOutstandingRewardsRequest
    ) -> QueryValidatorOutstandingRewardsResponse:
        """
        ValidatorOutstandingRewards queries rewards of a validator address.

        :param request: QueryValidatorOutstandingRewardsRequest
        :return: QueryValidatorOutstandingRewardsResponse
        """

    @abstractmethod
    def ValidatorSlashes(
        self, request: QueryValidatorSlashesRequest
    ) -> QueryValidatorSlashesResponse:
        """
        ValidatorSlashes queries slash events of a validator.

        :param request: QueryValidatorSlashesRequest
        :return: QueryValidatorSlashesResponse
        """



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ibc/applications/interchain_accounts/host/v1/host.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'ibc/applications/interchain_accounts/host/v1/host.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7ibc/applications/interchain_accounts/host/v1/host.proto\x12,ibc.applications.interchain_accounts.host.v1\x1a\x14gogoproto/gogo.proto\"j\n\x06Params\x12-\n\x0chost_enabled\x18\x01 \x01(\x08\x42\x17\xf2\xde\x1f\x13yaml:\"host_enabled\"\x12\x31\n\x0e\x61llow_messages\x18\x02 \x03(\tB\x19\xf2\xde\x1f\x15yaml:\"allow_messages\"BLZJgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/host/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.host.v1.host_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZJgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/host/types'
  _globals['_PARAMS'].fields_by_name['host_enabled']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['host_enabled']._serialized_options = b'\362\336\037\023yaml:\"host_enabled\"'
  _globals['_PARAMS'].fields_by_name['allow_messages']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['allow_messages']._serialized_options = b'\362\336\037\025yaml:\"allow_messages\"'
  _globals['_PARAMS']._serialized_start=127
  _globals['_PARAMS']._serialized_end=233
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/evidence/v1beta1/evidence.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/evidence/v1beta1/evidence.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cosmos/evidence/v1beta1/evidence.proto\x12\x17\x63osmos.evidence.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa8\x01\n\x0c\x45quivocation\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\x32\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\r\n\x05power\x18\x03 \x01(\x03\x12\x37\n\x11\x63onsensus_address\x18\x04 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"consensus_address\":\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\x42\x33Z-github.com/cosmos/cosmos-sdk/x/evidence/types\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.evidence.v1beta1.evidence_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/evidence/types\250\342\036\001'
  _globals['_EQUIVOCATION'].fields_by_name['time']._loaded_options = None
  _globals['_EQUIVOCATION'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EQUIVOCATION'].fields_by_name['consensus_address']._loaded_options = None
  _globals['_EQUIVOCATION'].fields_by_name['consensus_address']._serialized_options = b'\362\336\037\030yaml:\"consensus_address\"'
  _globals['_EQUIVOCATION']._loaded_options = None
  _globals['_EQUIVOCATION']._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _globals['_EQUIVOCATION']._serialized_start=123
  _globals['_EQUIVOCATION']._serialized_end=291
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Capability(_message.Message):
    __slots__ = ("index",)
    INDEX_FIELD_NUMBER: _ClassVar[int]
    index: int
    def __init__(self, index: _Optional[int] = ...) -> None: ...

class Owner(_message.Message):
    __slots__ = ("module", "name")
    MODULE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    module: str
    name: str
    def __init__(self, module: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class CapabilityOwners(_message.Message):
    __slots__ = ("owners",)
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    owners: _containers.RepeatedCompositeFieldContainer[Owner]
    def __init__(self, owners: _Optional[_Iterable[_Union[Owner, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/crypto/multisig/keys.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/crypto/multisig/keys.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/crypto/multisig/keys.proto\x12\x16\x63osmos.crypto.multisig\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"\x8c\x01\n\x11LegacyAminoPubKey\x12\'\n\tthreshold\x18\x01 \x01(\rB\x14\xf2\xde\x1f\x10yaml:\"threshold\"\x12H\n\x0bpublic_keys\x18\x02 \x03(\x0b\x32\x14.google.protobuf.AnyB\x1d\xe2\xde\x1f\x07PubKeys\xf2\xde\x1f\x0eyaml:\"pubkeys\":\x04\x88\xa0\x1f\x00\x42\x33Z1github.com/cosmos/cosmos-sdk/crypto/keys/multisigb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.multisig.keys_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/crypto/keys/multisig'
  _globals['_LEGACYAMINOPUBKEY'].fields_by_name['threshold']._loaded_options = None
  _globals['_LEGACYAMINOPUBKEY'].fields_by_name['threshold']._serialized_options = b'\362\336\037\020yaml:\"threshold\"'
  _globals['_LEGACYAMINOPUBKEY'].fields_by_name['public_keys']._loaded_options = None
  _globals['_LEGACYAMINOPUBKEY'].fields_by_name['public_keys']._serialized_options = b'\342\336\037\007PubKeys\362\336\037\016yaml:\"pubkeys\"'
  _globals['_LEGACYAMINOPUBKEY']._loaded_options = None
  _globals['_LEGACYAMINOPUBKEY']._serialized_options = b'\210\240\037\000'
  _globals['_LEGACYAMINOPUBKEY']._serialized_start=111
  _globals['_LEGACYAMINOPUBKEY']._serialized_end=251
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from cosmos.auth.v1beta1 import auth_pb2 as _auth_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BaseVestingAccount(_message.Message):
    __slots__ = ("base_account", "original_vesting", "delegated_free", "delegated_vesting", "end_time")
    BASE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    ORIGINAL_VESTING_FIELD_NUMBER: _ClassVar[int]
    DELEGATED_FREE_FIELD_NUMBER: _ClassVar[int]
    DELEGATED_VESTING_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    base_account: _auth_pb2.BaseAccount
    original_vesting: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    delegated_free: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    delegated_vesting: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    end_time: int
    def __init__(self, base_account: _Optional[_Union[_auth_pb2.BaseAccount, _Mapping]] = ..., original_vesting: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., delegated_free: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., delegated_vesting: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., end_time: _Optional[int] = ...) -> None: ...

class ContinuousVestingAccount(_message.Message):
    __slots__ = ("base_vesting_account", "start_time")
    BASE_VESTING_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    base_vesting_account: BaseVestingAccount
    start_time: int
    def __init__(self, base_vesting_account: _Optional[_Union[BaseVestingAccount, _Mapping]] = ..., start_time: _Optional[int] = ...) -> None: ...

class DelayedVestingAccount(_message.Message):
    __slots__ = ("base_vesting_account",)
    BASE_VESTING_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    base_vesting_account: BaseVestingAccount
    def __init__(self, base_vesting_account: _Optional[_Union[BaseVestingAccount, _Mapping]] = ...) -> None: ...

class Period(_message.Message):
    __slots__ = ("length", "amount")
    LENGTH_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    length: int
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    def __init__(self, length: _Optional[int] = ..., amount: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ...) -> None: ...

class PeriodicVestingAccount(_message.Message):
    __slots__ = ("base_vesting_account", "start_time", "vesting_periods")
    BASE_VESTING_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    VESTING_PERIODS_FIELD_NUMBER: _ClassVar[int]
    base_vesting_account: BaseVestingAccount
    start_time: int
    vesting_periods: _containers.RepeatedCompositeFieldContainer[Period]
    def __init__(self, base_vesting_account: _Optional[_Union[BaseVestingAccount, _Mapping]] = ..., start_time: _Optional[int] = ..., vesting_periods: _Optional[_Iterable[_Union[Period, _Mapping]]] = ...) -> None: ...

class PermanentLockedAccount(_message.Message):
    __slots__ = ("base_vesting_account",)
    BASE_VESTING_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    base_vesting_account: BaseVestingAccount
    def __init__(self, base_vesting_account: _Optional[_Union[BaseVestingAccount, _Mapping]] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MsgUnjail(_message.Message):
    __slots__ = ("validator_addr",)
    VALIDATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    validator_addr: str
    def __init__(self, validator_addr: _Optional[str] = ...) -> None: ...

class MsgUnjailResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from ibc.applications.transfer.v1 import transfer_pb2 as _transfer_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("port_id", "denom_traces", "params")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    DENOM_TRACES_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    denom_traces: _containers.RepeatedCompositeFieldContainer[_transfer_pb2.DenomTrace]
    params: _transfer_pb2.Params
    def __init__(self, port_id: _Optional[str] = ..., denom_traces: _Optional[_Iterable[_Union[_transfer_pb2.DenomTrace, _Mapping]]] = ..., params: _Optional[_Union[_transfer_pb2.Params, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ibc/applications/transfer/v1/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'ibc/applications/transfer/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ibc.applications.transfer.v1 import transfer_pb2 as ibc_dot_applications_dot_transfer_dot_v1_dot_transfer__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ibc/applications/transfer/v1/query.proto\x12\x1cibc.applications.transfer.v1\x1a\x14gogoproto/gogo.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a+ibc/applications/transfer/v1/transfer.proto\x1a\x1cgoogle/api/annotations.proto\"&\n\x16QueryDenomTraceRequest\x12\x0c\n\x04hash\x18\x01 \x01(\t\"X\n\x17QueryDenomTraceResponse\x12=\n\x0b\x64\x65nom_trace\x18\x01 \x01(\x0b\x32(.ibc.applications.transfer.v1.DenomTrace\"U\n\x17QueryDenomTracesRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xa7\x01\n\x18QueryDenomTracesResponse\x12N\n\x0c\x64\x65nom_traces\x18\x01 \x03(\x0b\x32(.ibc.applications.transfer.v1.DenomTraceB\x0e\xc8\xde\x1f\x00\xaa\xdf\x1f\x06Traces\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x14\n\x12QueryParamsRequest\"K\n\x13QueryParamsResponse\x12\x34\n\x06params\x18\x01 \x01(\x0b\x32$.ibc.applications.transfer.v1.Params\"&\n\x15QueryDenomHashRequest\x12\r\n\x05trace\x18\x01 \x01(\t\"&\n\x16QueryDenomHashResponse\x12\x0c\n\x04hash\x18\x01 \x01(\t2\xa4\x05\n\x05Query\x12\xac\x01\n\nDenomTrace\x12\x34.ibc.applications.transfer.v1.QueryDenomTraceRequest\x1a\x35.ibc.applications.transfer.v1.QueryDenomTraceResponse\"1\x82\xd3\xe4\x93\x02+\x12)/ibc/apps/transfer/v1/denom_traces/{hash}\x12\xa8\x01\n\x0b\x44\x65nomTraces\x12\x35.ibc.applications.transfer.v1.QueryDenomTracesRequest\x1a\x36.ibc.applications.transfer.v1.QueryDenomTracesResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/ibc/apps/transfer/v1/denom_traces\x12\x93\x01\n\x06Params\x12\x30.ibc.applications.transfer.v1.QueryParamsRequest\x1a\x31.ibc.applications.transfer.v1.QueryParamsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/ibc/apps/transfer/v1/params\x12\xaa\x01\n\tDenomHash\x12\x33.ibc.applications.transfer.v1.QueryDenomHashRequest\x1a\x34.ibc.applications.transfer.v1.QueryDenomHashResponse\"2\x82\xd3\xe4\x93\x02,\x12*/ibc/apps/transfer/v1/denom_hashes/{trace}B9Z7github.com/cosmos/ibc-go/v2/modules/apps/transfer/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/cosmos/ibc-go/v2/modules/apps/transfer/types'
  _globals['_QUERYDENOMTRACESRESPONSE'].fields_by_name['denom_traces']._loaded_options = None
  _globals['_QUERYDENOMTRACESRESPONSE'].fields_by_name['denom_traces']._serialized_options = b'\310\336\037\000\252\337\037\006Traces'
  _globals['_QUERY'].methods_by_name['DenomTrace']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomTrace']._serialized_options = b'\202\323\344\223\002+\022)/ibc/apps/transfer/v1/denom_traces/{hash}'
  _globals['_QUERY'].methods_by_name['DenomTraces']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomTraces']._serialized_options = b'\202\323\344\223\002$\022\"/ibc/apps/transfer/v1/denom_traces'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\036\022\034/ibc/apps/transfer/v1/params'
  _globals['_QUERY'].methods_by_name['DenomHash']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomHash']._serialized_options = b'\202\323\344\223\002,\022*/ibc/apps/transfer/v1/denom_hashes/{trace}'
  _globals['_QUERYDENOMTRACEREQUEST']._serialized_start=215
  _globals['_QUERYDENOMTRACEREQUEST']._serialized_end=253
  _globals['_QUERYDENOMTRACERESPONSE']._serialized_start=255
  _globals['_QUERYDENOMTRACERESPONSE']._serialized_end=343
  _globals['_QUERYDENOMTRACESREQUEST']._serialized_start=345
  _globals['_QUERYDENOMTRACESREQUEST']._serialized_end=430
  _globals['_QUERYDENOMTRACESRESPONSE']._serialized_start=433
  _globals['_QUERYDENOMTRACESRESPONSE']._serialized_end=600
  _globals['_QUERYPARAMSREQUEST']._serialized_start=602
  _globals['_QUERYPARAMSREQUEST']._serialized_end=622
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=624
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=699
  _globals['_QUERYDENOMHASHREQUEST']._serialized_start=701
  _globals['_QUERYDENOMHASHREQUEST']._serialized_end=739
  _globals['_QUERYDENOMHASHRESPONSE']._serialized_start=741
  _globals['_QUERYDENOMHASHRESPONSE']._serialized_end=779
  _globals['_QUERY']._serialized_start=782
  _globals['_QUERY']._serialized_end=1458
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tendermint/privval/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tendermint/privval/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tendermint.crypto import keys_pb2 as tendermint_dot_crypto_dot_keys__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1etendermint/privval/types.proto\x12\x12tendermint.privval\x1a\x1ctendermint/crypto/keys.proto\x1a\x1ctendermint/types/types.proto\x1a\x14gogoproto/gogo.proto\"6\n\x11RemoteSignerError\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"!\n\rPubKeyRequest\x12\x10\n\x08\x63hain_id\x18\x01 \x01(\t\"{\n\x0ePubKeyResponse\x12\x33\n\x07pub_key\x18\x01 \x01(\x0b\x32\x1c.tendermint.crypto.PublicKeyB\x04\xc8\xde\x1f\x00\x12\x34\n\x05\x65rror\x18\x02 \x01(\x0b\x32%.tendermint.privval.RemoteSignerError\"I\n\x0fSignVoteRequest\x12$\n\x04vote\x18\x01 \x01(\x0b\x32\x16.tendermint.types.Vote\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\"v\n\x12SignedVoteResponse\x12*\n\x04vote\x18\x01 \x01(\x0b\x32\x16.tendermint.types.VoteB\x04\xc8\xde\x1f\x00\x12\x34\n\x05\x65rror\x18\x02 \x01(\x0b\x32%.tendermint.privval.RemoteSignerError\"U\n\x13SignProposalRequest\x12,\n\x08proposal\x18\x01 \x01(\x0b\x32\x1a.tendermint.types.Proposal\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\"\x82\x01\n\x16SignedProposalResponse\x12\x32\n\x08proposal\x18\x01 \x01(\x0b\x32\x1a.tendermint.types.ProposalB\x04\xc8\xde\x1f\x00\x12\x34\n\x05\x65rror\x18\x02 \x01(\x0b\x32%.tendermint.privval.RemoteSignerError\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\xa6\x04\n\x07Message\x12<\n\x0fpub_key_request\x18\x01 \x01(\x0b\x32!.tendermint.privval.PubKeyRequestH\x00\x12>\n\x10pub_key_response\x18\x02 \x01(\x0b\x32\".tendermint.privval.PubKeyResponseH\x00\x12@\n\x11sign_vote_request\x18\x03 \x01(\x0b\x32#.tendermint.privval.SignVoteRequestH\x00\x12\x46\n\x14signed_vote_response\x18\x04 \x01(\x0b\x32&.tendermint.privval.SignedVoteResponseH\x00\x12H\n\x15sign_proposal_request\x18\x05 \x01(\x0b\x32\'.tendermint.privval.SignProposalRequestH\x00\x12N\n\x18signed_proposal_response\x18\x06 \x01(\x0b\x32*.tendermint.privval.SignedProposalResponseH\x00\x12\x37\n\x0cping_request\x18\x07 \x01(\x0b\x32\x1f.tendermint.privval.PingRequestH\x00\x12\x39\n\rping_response\x18\x08 \x01(\x0b\x32 .tendermint.privval.PingResponseH\x00\x42\x05\n\x03sum*\xa8\x01\n\x06\x45rrors\x12\x12\n\x0e\x45RRORS_UNKNOWN\x10\x00\x12\x1e\n\x1a\x45RRORS_UNEXPECTED_RESPONSE\x10\x01\x12\x18\n\x14\x45RRORS_NO_CONNECTION\x10\x02\x12\x1d\n\x19\x45RRORS_CONNECTION_TIMEOUT\x10\x03\x12\x17\n\x13\x45RRORS_READ_TIMEOUT\x10\x04\x12\x18\n\x14\x45RRORS_WRITE_TIMEOUT\x10\x05\x42;Z9github.com/tendermint/tendermint/proto/tendermint/privvalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.privval.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/tendermint/tendermint/proto/tendermint/privval'
  _globals['_PUBKEYRESPONSE'].fields_by_name['pub_key']._loaded_options = None
  _globals['_PUBKEYRESPONSE'].fields_by_name['pub_key']._serialized_options = b'\310\336\037\000'
  _globals['_SIGNEDVOTERESPONSE'].fields_by_name['vote']._loaded_options = None
  _globals['_SIGNEDVOTERESPONSE'].fields_by_name['vote']._serialized_options = b'\310\336\037\000'
  _globals['_SIGNEDPROPOSALRESPONSE'].fields_by_name['proposal']._loaded_options = None
  _globals['_SIGNEDPROPOSALRESPONSE'].fields_by_name['proposal']._serialized_options = b'\310\336\037\000'
  _globals['_ERRORS']._serialized_start=1352
  _globals['_ERRORS']._serialized_end=1520
  _globals['_REMOTESIGNERERROR']._serialized_start=136
  _globals['_REMOTESIGNERERROR']._serialized_end=190
  _globals['_PUBKEYREQUEST']._serialized_start=192
  _globals['_PUBKEYREQUEST']._serialized_end=225
  _globals['_PUBKEYRESPONSE']._serialized_start=227
  _globals['_PUBKEYRESPONSE']._serialized_end=350
  _globals['_SIGNVOTEREQUEST']._serialized_start=352
  _globals['_SIGNVOTEREQUEST']._serialized_end=425
  _globals['_SIGNEDVOTERESPONSE']._serialized_start=427
  _globals['_SIGNEDVOTERESPONSE']._serialized_end=545
  _globals['_SIGNPROPOSALREQUEST']._serialized_start=547
  _globals['_SIGNPROPOSALREQUEST']._serialized_end=632
  _globals['_SIGNEDPROPOSALRESPONSE']._serialized_start=635
  _globals['_SIGNEDPROPOSALRESPONSE']._serialized_end=765
  _globals['_PINGREQUEST']._serialized_start=767
  _globals['_PINGREQUEST']._serialized_end=780
  _globals['_PINGRESPONSE']._serialized_start=782
  _globals['_PINGRESPONSE']._serialized_end=796
  _globals['_MESSAGE']._serialized_start=799
  _globals['_MESSAGE']._serialized_end=1349
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/crypto/v1/keys.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/crypto/v1/keys.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63ometbft/crypto/v1/keys.proto\x12\x12\x63ometbft.crypto.v1\x1a\x14gogoproto/gogo.proto\"p\n\tPublicKey\x12\x11\n\x07\x65\x64\x32\x35\x35\x31\x39\x18\x01 \x01(\x0cH\x00\x12\x13\n\tsecp256k1\x18\x02 \x01(\x0cH\x00\x12\x12\n\x08\x62ls12381\x18\x03 \x01(\x0cH\x00\x12\x16\n\x0csecp256k1eth\x18\x04 \x01(\x0cH\x00:\x08\xe8\xa0\x1f\x01\xe8\xa1\x1f\x01\x42\x05\n\x03sumB5Z3github.com/cometbft/cometbft/api/cometbft/crypto/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.crypto.v1.keys_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/cometbft/cometbft/api/cometbft/crypto/v1'
  _globals['_PUBLICKEY']._loaded_options = None
  _globals['_PUBLICKEY']._serialized_options = b'\350\240\037\001\350\241\037\001'
  _globals['_PUBLICKEY']._serialized_start=75
  _globals['_PUBLICKEY']._serialized_end=187
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ibc/applications/interchain_accounts/v1/genesis.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'ibc/applications/interchain_accounts/v1/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.applications.interchain_accounts.controller.v1 import controller_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_controller__pb2
from ibc.applications.interchain_accounts.host.v1 import host_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_host_dot_v1_dot_host__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5ibc/applications/interchain_accounts/v1/genesis.proto\x12\'ibc.applications.interchain_accounts.v1\x1a\x14gogoproto/gogo.proto\x1a\x43ibc/applications/interchain_accounts/controller/v1/controller.proto\x1a\x37ibc/applications/interchain_accounts/host/v1/host.proto\"\x95\x02\n\x0cGenesisState\x12\x8a\x01\n\x18\x63ontroller_genesis_state\x18\x01 \x01(\x0b\x32?.ibc.applications.interchain_accounts.v1.ControllerGenesisStateB\'\xc8\xde\x1f\x00\xf2\xde\x1f\x1fyaml:\"controller_genesis_state\"\x12x\n\x12host_genesis_state\x18\x02 \x01(\x0b\x32\x39.ibc.applications.interchain_accounts.v1.HostGenesisStateB!\xc8\xde\x1f\x00\xf2\xde\x1f\x19yaml:\"host_genesis_state\"\"\xf2\x02\n\x16\x43ontrollerGenesisState\x12o\n\x0f\x61\x63tive_channels\x18\x01 \x03(\x0b\x32\x36.ibc.applications.interchain_accounts.v1.ActiveChannelB\x1e\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:\"active_channels\"\x12\x85\x01\n\x13interchain_accounts\x18\x02 \x03(\x0b\x32\x44.ibc.applications.interchain_accounts.v1.RegisteredInterchainAccountB\"\xc8\xde\x1f\x00\xf2\xde\x1f\x1ayaml:\"interchain_accounts\"\x12\r\n\x05ports\x18\x03 \x03(\t\x12P\n\x06params\x18\x04 \x01(\x0b\x32:.ibc.applications.interchain_accounts.controller.v1.ParamsB\x04\xc8\xde\x1f\x00\"\xe5\x02\n\x10HostGenesisState\x12o\n\x0f\x61\x63tive_channels\x18\x01 \x03(\x0b\x32\x36.ibc.applications.interchain_accounts.v1.ActiveChannelB\x1e\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:\"active_channels\"\x12\x85\x01\n\x13interchain_accounts\x18\x02 \x03(\x0b\x32\x44.ibc.applications.interchain_accounts.v1.RegisteredInterchainAccountB\"\xc8\xde\x1f\x00\xf2\xde\x1f\x1ayaml:\"interchain_accounts\"\x12\x0c\n\x04port\x18\x03 \x01(\t\x12J\n\x06params\x18\x04 \x01(\x0b\x32\x34.ibc.applications.interchain_accounts.host.v1.ParamsB\x04\xc8\xde\x1f\x00\"\x90\x01\n\rActiveChannel\x12/\n\rconnection_id\x18\x01 \x01(\tB\x18\xf2\xde\x1f\x14yaml:\"connection_id\"\x12#\n\x07port_id\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12)\n\nchannel_id\x18\x03 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\"\xa8\x01\n\x1bRegisteredInterchainAccount\x12/\n\rconnection_id\x18\x01 \x01(\tB\x18\xf2\xde\x1f\x14yaml:\"connection_id\"\x12#\n\x07port_id\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12\x33\n\x0f\x61\x63\x63ount_address\x18\x03 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"account_address\"BGZEgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZEgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/types'
  _globals['_GENESISSTATE'].fields_by_name['controller_genesis_state']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['controller_genesis_state']._serialized_options = b'\310\336\037\000\362\336\037\037yaml:\"controller_genesis_state\"'
  _globals['_GENESISSTATE'].fields_by_name['host_genesis_state']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['host_genesis_state']._serialized_options = b'\310\336\037\000\362\336\037\031yaml:\"host_genesis_state\"'
  _globals['_CONTROLLERGENESISSTATE'].fields_by_name['active_channels']._loaded_options = None
  _globals['_CONTROLLERGENESISSTATE'].fields_by_name['active_channels']._serialized_options = b'\310\336\037\000\362\336\037\026yaml:\"active_channels\"'
  _globals['_CONTROLLERGENESISSTATE'].fields_by_name['interchain_accounts']._loaded_options = None
  _globals['_CONTROLLERGENESISSTATE'].fields_by_name['interchain_accounts']._serialized_options = b'\310\336\037\000\362\336\037\032yaml:\"interchain_accounts\"'
  _globals['_CONTROLLERGENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_CONTROLLERGENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_HOSTGENESISSTATE'].fields_by_name['active_channels']._loaded_options = None
  _globals['_HOSTGENESISSTATE'].fields_by_name['active_channels']._serialized_options = b'\310\336\037\000\362\336\037\026yaml:\"active_channels\"'
  _globals['_HOSTGENESISSTATE'].fields_by_name['interchain_accounts']._loaded_options = None
  _globals['_HOSTGENESISSTATE'].fields_by_name['interchain_accounts']._serialized_options = b'\310\336\037\000\362\336\037\032yaml:\"interchain_accounts\"'
  _globals['_HOSTGENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_HOSTGENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_ACTIVECHANNEL'].fields_by_name['connection_id']._loaded_options = None
  _globals['_ACTIVECHANNEL'].fields_by_name['connection_id']._serialized_options = b'\362\336\037\024yaml:\"connection_id\"'
  _globals['_ACTIVECHANNEL'].fields_by_name['port_id']._loaded_options = None
  _globals['_ACTIVECHANNEL'].fields_by_name['port_id']._serialized_options = b'\362\336\037\016yaml:\"port_id\"'
  _globals['_ACTIVECHANNEL'].fields_by_name['channel_id']._loaded_options = None
  _globals['_ACTIVECHANNEL'].fields_by_name['channel_id']._serialized_options = b'\362\336\037\021yaml:\"channel_id\"'
  _globals['_REGISTEREDINTERCHAINACCOUNT'].fields_by_name['connection_id']._loaded_options = None
  _globals['_REGISTEREDINTERCHAINACCOUNT'].fields_by_name['connection_id']._serialized_options = b'\362\336\037\024yaml:\"connection_id\"'
  _globals['_REGISTEREDINTERCHAINACCOUNT'].fields_by_name['port_id']._loaded_options = None
  _globals['_REGISTEREDINTERCHAINACCOUNT'].fields_by_name['port_id']._serialized_options = b'\362\336\037\016yaml:\"port_id\"'
  _globals['_REGISTEREDINTERCHAINACCOUNT'].fields_by_name['account_address']._loaded_options = None
  _globals['_REGISTEREDINTERCHAINACCOUNT'].fields_by_name['account_address']._serialized_options = b'\362\336\037\026yaml:\"account_address\"'
  _globals['_GENESISSTATE']._serialized_start=247
  _globals['_GENESISSTATE']._serialized_end=524
  _globals['_CONTROLLERGENESISSTATE']._serialized_start=527
  _globals['_CONTROLLERGENESISSTATE']._serialized_end=897
  _globals['_HOSTGENESISSTATE']._serialized_start=900
  _globals['_HOSTGENESISSTATE']._serialized_end=1257
  _globals['_ACTIVECHANNEL']._serialized_start=1260
  _globals['_ACTIVECHANNEL']._serialized_end=1404
  _globals['_REGISTEREDINTERCHAINACCOUNT']._serialized_start=1407
  _globals['_REGISTEREDINTERCHAINACCOUNT']._serialized_end=1575
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from neurion.fusion import tx_pb2 as neurion_dot_fusion_dot_tx__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in neurion/fusion/tx_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class MsgStub(object):
    """Msg defines the Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UpdateParams = channel.unary_unary(
                '/neurion.fusion.Msg/UpdateParams',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgUpdateParams.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
                _registered_method=True)
        self.ApplyCreator = channel.unary_unary(
                '/neurion.fusion.Msg/ApplyCreator',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgApplyCreator.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgApplyCreatorResponse.FromString,
                _registered_method=True)
        self.ApproveApplication = channel.unary_unary(
                '/neurion.fusion.Msg/ApproveApplication',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgApproveApplication.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgApproveApplicationResponse.FromString,
                _registered_method=True)
        self.RejectApplication = channel.unary_unary(
                '/neurion.fusion.Msg/RejectApplication',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgRejectApplication.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgRejectApplicationResponse.FromString,
                _registered_method=True)
        self.CreateTask = channel.unary_unary(
                '/neurion.fusion.Msg/CreateTask',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgCreateTask.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgCreateTaskResponse.FromString,
                _registered_method=True)
        self.StartTask = channel.unary_unary(
                '/neurion.fusion.Msg/StartTask',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgStartTask.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgStartTaskResponse.FromString,
                _registered_method=True)
        self.ProposeModel = channel.unary_unary(
                '/neurion.fusion.Msg/ProposeModel',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgProposeModel.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgProposeModelResponse.FromString,
                _registered_method=True)
        self.RegisterProposer = channel.unary_unary(
                '/neurion.fusion.Msg/RegisterProposer',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgRegisterProposer.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgRegisterProposerResponse.FromString,
                _registered_method=True)
        self.RegisterValidator = channel.unary_unary(
                '/neurion.fusion.Msg/RegisterValidator',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgRegisterValidator.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgRegisterValidatorResponse.FromString,
                _registered_method=True)
        self.StartTesting = channel.unary_unary(
                '/neurion.fusion.Msg/StartTesting',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgStartTesting.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgStartTestingResponse.FromString,
                _registered_method=True)
        self.RequestValidationTask = channel.unary_unary(
                '/neurion.fusion.Msg/RequestValidationTask',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgRequestValidationTask.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgRequestValidationTaskResponse.FromString,
                _registered_method=True)
        self.SubmitScore = channel.unary_unary(
                '/neurion.fusion.Msg/SubmitScore',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgSubmitScore.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgSubmitScoreResponse.FromString,
                _registered_method=True)
        self.DisputeModelScore = channel.unary_unary(
                '/neurion.fusion.Msg/DisputeModelScore',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgDisputeModelScore.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgDisputeModelScoreResponse.FromString,
                _registered_method=True)
        self.StartNewRound = channel.unary_unary(
                '/neurion.fusion.Msg/StartNewRound',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgStartNewRound.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgStartNewRoundResponse.FromString,
                _registered_method=True)
        self.TerminateTask = channel.unary_unary(
                '/neurion.fusion.Msg/TerminateTask',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgTerminateTask.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgTerminateTaskResponse.FromString,
                _registered_method=True)
        self.StakeToTask = channel.unary_unary(
                '/neurion.fusion.Msg/StakeToTask',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgStakeToTask.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgStakeToTaskResponse.FromString,
                _registered_method=True)
        self.ClaimTaskReward = channel.unary_unary(
                '/neurion.fusion.Msg/ClaimTaskReward',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgClaimTaskReward.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgClaimTaskRewardResponse.FromString,
                _registered_method=True)
        self.UnstakeFromTask = channel.unary_unary(
                '/neurion.fusion.Msg/UnstakeFromTask',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgUnstakeFromTask.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgUnstakeFromTaskResponse.FromString,
                _registered_method=True)
        self.DisclaimCreatorStatus = channel.unary_unary(
                '/neurion.fusion.Msg/DisclaimCreatorStatus',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgDisclaimCreatorStatus.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgDisclaimCreatorStatusResponse.FromString,
                _registered_method=True)
        self.AbortTask = channel.unary_unary(
                '/neurion.fusion.Msg/AbortTask',
                request_serializer=neurion_dot_fusion_dot_tx__pb2.MsgAbortTask.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgAbortTaskResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the Msg service.
    """

    def UpdateParams(self, request, context):
        """UpdateParams defines a (governance) operation for updating the module
        parameters. The authority defaults to the x/gov module account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyCreator(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApproveApplication(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RejectApplication(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProposeModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterProposer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterValidator(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartTesting(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RequestValidationTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubmitScore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisputeModelScore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartNewRound(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TerminateTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StakeToTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClaimTaskReward(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnstakeFromTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisclaimCreatorStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AbortTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UpdateParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateParams,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgUpdateParams.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgUpdateParamsResponse.SerializeToString,
            ),
            'ApplyCreator': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyCreator,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgApplyCreator.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgApplyCreatorResponse.SerializeToString,
            ),
            'ApproveApplication': grpc.unary_unary_rpc_method_handler(
                    servicer.ApproveApplication,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgApproveApplication.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgApproveApplicationResponse.SerializeToString,
            ),
            'RejectApplication': grpc.unary_unary_rpc_method_handler(
                    servicer.RejectApplication,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgRejectApplication.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgRejectApplicationResponse.SerializeToString,
            ),
            'CreateTask': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTask,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgCreateTask.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgCreateTaskResponse.SerializeToString,
            ),
            'StartTask': grpc.unary_unary_rpc_method_handler(
                    servicer.StartTask,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgStartTask.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgStartTaskResponse.SerializeToString,
            ),
            'ProposeModel': grpc.unary_unary_rpc_method_handler(
                    servicer.ProposeModel,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgProposeModel.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgProposeModelResponse.SerializeToString,
            ),
            'RegisterProposer': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterProposer,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgRegisterProposer.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgRegisterProposerResponse.SerializeToString,
            ),
            'RegisterValidator': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterValidator,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgRegisterValidator.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgRegisterValidatorResponse.SerializeToString,
            ),
            'StartTesting': grpc.unary_unary_rpc_method_handler(
                    servicer.StartTesting,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgStartTesting.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgStartTestingResponse.SerializeToString,
            ),
            'RequestValidationTask': grpc.unary_unary_rpc_method_handler(
                    servicer.RequestValidationTask,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgRequestValidationTask.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgRequestValidationTaskResponse.SerializeToString,
            ),
            'SubmitScore': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitScore,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgSubmitScore.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgSubmitScoreResponse.SerializeToString,
            ),
            'DisputeModelScore': grpc.unary_unary_rpc_method_handler(
                    servicer.DisputeModelScore,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgDisputeModelScore.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgDisputeModelScoreResponse.SerializeToString,
            ),
            'StartNewRound': grpc.unary_unary_rpc_method_handler(
                    servicer.StartNewRound,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgStartNewRound.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgStartNewRoundResponse.SerializeToString,
            ),
            'TerminateTask': grpc.unary_unary_rpc_method_handler(
                    servicer.TerminateTask,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgTerminateTask.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgTerminateTaskResponse.SerializeToString,
            ),
            'StakeToTask': grpc.unary_unary_rpc_method_handler(
                    servicer.StakeToTask,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgStakeToTask.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgStakeToTaskResponse.SerializeToString,
            ),
            'ClaimTaskReward': grpc.unary_unary_rpc_method_handler(
                    servicer.ClaimTaskReward,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgClaimTaskReward.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgClaimTaskRewardResponse.SerializeToString,
            ),
            'UnstakeFromTask': grpc.unary_unary_rpc_method_handler(
                    servicer.UnstakeFromTask,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgUnstakeFromTask.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgUnstakeFromTaskResponse.SerializeToString,
            ),
            'DisclaimCreatorStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.DisclaimCreatorStatus,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgDisclaimCreatorStatus.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgDisclaimCreatorStatusResponse.SerializeToString,
            ),
            'AbortTask': grpc.unary_unary_rpc_method_handler(
                    servicer.AbortTask,
                    request_deserializer=neurion_dot_fusion_dot_tx__pb2.MsgAbortTask.FromString,
                    response_serializer=neurion_dot_fusion_dot_tx__pb2.MsgAbortTaskResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'neurion.fusion.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('neurion.fusion.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the Msg service.
    """

    @staticmethod
    def UpdateParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/UpdateParams',
            neurion_dot_fusion_dot_tx__pb2.MsgUpdateParams.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ApplyCreator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/ApplyCreator',
            neurion_dot_fusion_dot_tx__pb2.MsgApplyCreator.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgApplyCreatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ApproveApplication(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/ApproveApplication',
            neurion_dot_fusion_dot_tx__pb2.MsgApproveApplication.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgApproveApplicationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RejectApplication(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/RejectApplication',
            neurion_dot_fusion_dot_tx__pb2.MsgRejectApplication.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgRejectApplicationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/CreateTask',
            neurion_dot_fusion_dot_tx__pb2.MsgCreateTask.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgCreateTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StartTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/StartTask',
            neurion_dot_fusion_dot_tx__pb2.MsgStartTask.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgStartTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ProposeModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/ProposeModel',
            neurion_dot_fusion_dot_tx__pb2.MsgProposeModel.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgProposeModelResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisterProposer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/RegisterProposer',
            neurion_dot_fusion_dot_tx__pb2.MsgRegisterProposer.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgRegisterProposerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisterValidator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/RegisterValidator',
            neurion_dot_fusion_dot_tx__pb2.MsgRegisterValidator.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgRegisterValidatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StartTesting(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/StartTesting',
            neurion_dot_fusion_dot_tx__pb2.MsgStartTesting.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgStartTestingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RequestValidationTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/RequestValidationTask',
            neurion_dot_fusion_dot_tx__pb2.MsgRequestValidationTask.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgRequestValidationTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SubmitScore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/SubmitScore',
            neurion_dot_fusion_dot_tx__pb2.MsgSubmitScore.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgSubmitScoreResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DisputeModelScore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/DisputeModelScore',
            neurion_dot_fusion_dot_tx__pb2.MsgDisputeModelScore.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgDisputeModelScoreResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StartNewRound(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/StartNewRound',
            neurion_dot_fusion_dot_tx__pb2.MsgStartNewRound.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgStartNewRoundResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TerminateTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/TerminateTask',
            neurion_dot_fusion_dot_tx__pb2.MsgTerminateTask.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgTerminateTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StakeToTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/StakeToTask',
            neurion_dot_fusion_dot_tx__pb2.MsgStakeToTask.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgStakeToTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ClaimTaskReward(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/ClaimTaskReward',
            neurion_dot_fusion_dot_tx__pb2.MsgClaimTaskReward.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgClaimTaskRewardResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UnstakeFromTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/UnstakeFromTask',
            neurion_dot_fusion_dot_tx__pb2.MsgUnstakeFromTask.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgUnstakeFromTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DisclaimCreatorStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/DisclaimCreatorStatus',
            neurion_dot_fusion_dot_tx__pb2.MsgDisclaimCreatorStatus.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgDisclaimCreatorStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AbortTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Msg/AbortTask',
            neurion_dot_fusion_dot_tx__pb2.MsgAbortTask.SerializeToString,
            neurion_dot_fusion_dot_tx__pb2.MsgAbortTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/types/v2/block.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/types/v2/block.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.types.v2 import types_pb2 as cometbft_dot_types_dot_v2_dot_types__pb2
from cometbft.types.v2 import evidence_pb2 as cometbft_dot_types_dot_v2_dot_evidence__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63ometbft/types/v2/block.proto\x12\x11\x63ometbft.types.v2\x1a\x1d\x63ometbft/types/v2/types.proto\x1a cometbft/types/v2/evidence.proto\x1a\x14gogoproto/gogo.proto\"\xce\x01\n\x05\x42lock\x12/\n\x06header\x18\x01 \x01(\x0b\x32\x19.cometbft.types.v2.HeaderB\x04\xc8\xde\x1f\x00\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.cometbft.types.v2.DataB\x04\xc8\xde\x1f\x00\x12\x37\n\x08\x65vidence\x18\x03 \x01(\x0b\x32\x1f.cometbft.types.v2.EvidenceListB\x04\xc8\xde\x1f\x00\x12.\n\x0blast_commit\x18\x04 \x01(\x0b\x32\x19.cometbft.types.v2.CommitB4Z2github.com/cometbft/cometbft/api/cometbft/types/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v2.block_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2github.com/cometbft/cometbft/api/cometbft/types/v2'
  _globals['_BLOCK'].fields_by_name['header']._loaded_options = None
  _globals['_BLOCK'].fields_by_name['header']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCK'].fields_by_name['data']._loaded_options = None
  _globals['_BLOCK'].fields_by_name['data']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCK'].fields_by_name['evidence']._loaded_options = None
  _globals['_BLOCK'].fields_by_name['evidence']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCK']._serialized_start=140
  _globals['_BLOCK']._serialized_end=346
# @@protoc_insertion_point(module_scope)
